@@ -37,7 +37,7 @@ def _process(prefix, file_path, obj):
         file_content = re.sub(re.escape(origin_c),
                               new_content, file_content, count=1)
 
-    with open("%s%s" % (prefix, file_path.name), "w", encoding="utf-8") as f:
+    with open(this_aub_path.joinpath("%s%s" % (prefix, file_path.name)), "w", encoding="utf-8") as f:
         f.write(file_content)
 
 
